import type { IFlowGraphBlockConfiguration } from "./flowGraphBlock.js";
import { FlowGraphExecutionBlock } from "./flowGraphExecutionBlock.js";
import type { FlowGraphSignalConnection } from "./flowGraphSignalConnection.js";
/**
 * An execution block that has an out signal. This signal is triggered when the synchronous execution of this block is done.
 * Most execution blocks will inherit from this, except for the ones that have multiple signals to be triggered.
 * (such as if blocks)
 */
export declare abstract class FlowGraphExecutionBlockWithOutSignal extends FlowGraphExecutionBlock {
    /**
     * Output connection: The signal that is synchronous triggered when the execution of this block is done.
     * Note that is case of events or async you might want to use the `done` signal instead.
     */
    readonly out: FlowGraphSignalConnection;
    protected constructor(config?: IFlowGraphBlockConfiguration);
}
