import { NodeMaterialBlock } from "../nodeMaterialBlock.js";
import type { NodeMaterialBuildState } from "../nodeMaterialBuildState.js";
import type { NodeMaterialConnectionPoint } from "../nodeMaterialBlockConnectionPoint.js";
import { Vector2 } from "../../../Maths/math.vector.js";
import type { Scene } from "../../../scene.js";
/**
 * Block used to remap a float from a range to a new one
 */
export declare class RemapBlock extends NodeMaterialBlock {
    /**
     * Gets or sets the source range
     */
    sourceRange: Vector2;
    /**
     * Gets or sets the target range
     */
    targetRange: Vector2;
    /**
     * Creates a new RemapBlock
     * @param name defines the block name
     */
    constructor(name: string);
    /**
     * Gets the current class name
     * @returns the class name
     */
    getClassName(): string;
    /**
     * Gets the input component
     */
    get input(): NodeMaterialConnectionPoint;
    /**
     * Gets the source min input component
     */
    get sourceMin(): NodeMaterialConnectionPoint;
    /**
     * Gets the source max input component
     */
    get sourceMax(): NodeMaterialConnectionPoint;
    /**
     * Gets the target min input component
     */
    get targetMin(): NodeMaterialConnectionPoint;
    /**
     * Gets the target max input component
     */
    get targetMax(): NodeMaterialConnectionPoint;
    /**
     * Gets the output component
     */
    get output(): NodeMaterialConnectionPoint;
    protected _buildBlock(state: NodeMaterialBuildState): this;
    protected _dumpPropertiesCode(): string;
    serialize(): any;
    _deserialize(serializationObject: any, scene: Scene, rootUrl: string): void;
}
