/**
 * Class used to store custom tags
 */
export declare class Tags {
    /**
     * Adds support for tags on the given object
     * @param obj defines the object to use
     */
    static EnableFor(obj: any): void;
    /**
     * Removes tags support
     * @param obj defines the object to use
     */
    static DisableFor(obj: any): void;
    /**
     * Gets a boolean indicating if the given object has tags
     * @param obj defines the object to use
     * @returns a boolean
     */
    static HasTags(obj: any): boolean;
    /**
     * Gets the tags available on a given object
     * @param obj defines the object to use
     * @param asString defines if the tags must be returned as a string instead of an array of strings
     * @returns the tags
     */
    static GetTags(obj: any, asString?: boolean): any;
    /**
     * Adds tags to an object
     * @param obj defines the object to use
     * @param tagsString defines the tag string. The tags 'true' and 'false' are reserved and cannot be used as tags.
     * A tag cannot start with '||', '&&', and '!'. It cannot contain whitespaces
     */
    static AddTagsTo(obj: any, tagsString: string): void;
    /**
     * @internal
     */
    static _AddTagTo(obj: any, tag: string): void;
    /**
     * Removes specific tags from a specific object
     * @param obj defines the object to use
     * @param tagsString defines the tags to remove
     */
    static RemoveTagsFrom(obj: any, tagsString: string): void;
    /**
     * @internal
     */
    static _RemoveTagFrom(obj: any, tag: string): void;
    /**
     * Defines if tags hosted on an object match a given query
     * @param obj defines the object to use
     * @param tagsQuery defines the tag query
     * @returns a boolean
     */
    static MatchesQuery(obj: any, tagsQuery: string): boolean;
}
